@@ -1,5 +1,5 @@
 package Util::Medley::Logger;
-$Util::Medley::Logger::VERSION = '0.040';
+$Util::Medley::Logger::VERSION = '0.041';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -23,7 +23,7 @@ Util::Medley::Logger - Yet another class for logging.
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =cut
 
@@ -863,8 +863,8 @@ method _getLogLevel () {
 }
 
 method _isLogLevelValid (Str $level) {
-	
-    if ( $self->_logLevelMap->{$level} ) {
+
+    if ( defined $self->_logLevelMap->{$level} ) {
 		return 1;
 	}
 
